import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '../views/layout/Layout'

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
*                                if not set alwaysShow, only more than one route under the children
*                                it will becomes nested mode, otherwise not show the root menu
* redirect: noredirect           if `redirect:noredirect` will no redirect in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
* meta : {
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
  }
**/
export const constantRouterMap = [
  { path: '/login', component: () => import('@/views/login/index'), hidden: true },
  { path: '/404', component: () => import('@/views/404'), hidden: true },

  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    name: 'Dashboard',
    hidden: true,
    children: [{
      path: 'dashboard',
      component: () => import('@/views/allFile/index')
    }]
  },

  {
    path: '/allFile',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'allFile',
        component: () => import('@/views/allFile/index'),
        meta: { title: '全部文件', icon: 'el-icon-document' }
      }
    ]
  },

  {
    path: '/fileDetail',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'fileDetail',
        name: 'fileDetail',
        component: () => import('@/views/fileDetail/index'),
        meta: { title: '全部文件' }
      }
    ]
  },

  {
    path: '/browse',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'Browse',
        component: () => import('@/views/browse/index'),
        meta: { title: '最近浏览', icon: 'el-icon-tickets' }
      }
    ]
  },

  // {
  //   path: '/recycleBin',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'index',
  //       name: 'RecycleBin',
  //       component: () => import('@/views/recycleBin/index'),
  //       meta: { title: '回收站', icon: 'el-icon-delete' }
  //     }
  //   ]
  // },

  { path: '*', redirect: '/404', hidden: true }
]

export default new Router({
  // mode: 'history', //后端支持可开
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRouterMap
})
