import { logout, getInfo, loginCode, loginSuccess, sendMag, loginByPhone } from '@/api/login'
import { getToken, removeToken } from '@/utils/auth'

const user = {
  state: {
    token: getToken(),
    name: '',
    avatar: '',
    roles: [],
    code: '',
    codeNum: '',
    loginUser: {}
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_CODE: (state, code) => {
      state.code = code.qrCode
      state.codeNum = code.code
    },
    SET_LOGIN: (state, loginData) => {
      state.loginUser = loginData.data
    }
  },

  actions: {

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo(getToken()).then(response => {
          const data = response.data
          commit('SET_NAME', data.nickName)
          commit('SET_AVATAR', data.avatar)
          resolve(response)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 登出
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          removeToken()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    },
    // 获取登录二维码
    LoginCode({ commit }) {
      return new Promise((resolve, reject) => {
        loginCode().then(response => {
          const data = response.data
          commit('SET_CODE', data)
          // console.log(this._actions)
          // this._actions.loginSuccess[0]()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取登录二维码
    loginSuccess({ commit, state }) {
      return new Promise((resolve, reject) => {
        loginSuccess(state.codeNum).then(response => {
          // const data = response.data.data
          if (response) {
            commit('SET_LOGIN', response)
            resolve(response)
          } else {
            reject('错误')
          }
        })
      })
    },
    // 发送手机验证码
    sendMag({ commit }, form) {
      return new Promise((resolve, reject) => {
        sendMag(form.username).then(response => {
          if (response) {
            resolve(response)
          } else {
            reject('错误')
          }
        })
      })
    },
    // 验证码登录
    loginByPhone({ commit }, form) {
      return new Promise((resolve, reject) => {
        loginByPhone(form).then(response => {
          if (response) {
            commit('SET_LOGIN', response)
            resolve(response)
          } else {
            reject('错误')
          }
        })
      })
    }
  }
}

export default user
